@@ -1,8 +1,9 @@
-from plume.record import Record, FrameSample
-from plume.samples.unity.game_object_pb2 import GameObjectUpdate
-from plume.samples.unity.identifiers_pb2 import GameObjectIdentifier
 from typing import Optional
 
+from ..record import Record
+from ..samples.unity.game_object_pb2 import GameObjectUpdate
+from ..samples.unity.identifiers_pb2 import GameObjectIdentifier
+
 
 def find_game_object_identifiers(record: Record, name: str) -> list[GameObjectIdentifier]:
     identifiers: list[GameObjectIdentifier] = []
